@@ -7,6 +7,7 @@ var NAMESPACE = utils.NAMESPACE;
 var attributes = require('./attributes');
 var Node = require('./Node');
 var NodeList = require('./NodeList');
+var NodeUtils = require('./NodeUtils');
 var FilteredElementList = require('./FilteredElementList');
 var DOMException = require('./DOMException');
 var DOMTokenList = require('./DOMTokenList');
@@ -98,7 +99,15 @@ Element.prototype = Object.create(ContainerNode.prototype, {
       // "the attribute must return the result of running the HTML fragment
       // serialization algorithm on a fictional node whose only child is
       // the context object"
-      return this._serializeOne({ nodeType: 0 });
+      //
+      // The serialization logic is intentionally implemented in a separate
+      // `NodeUtils` helper instead of the more obvious choice of a private
+      // `_serializeOne()` method on the `Node.prototype` in order to avoid
+      // the megamorphic `this._serializeOne` property access, which reduces
+      // performance unnecessarily. If you need specialized behavior for a
+      // certain subclass, you'll need to implement that in `NodeUtils`.
+      // See https://github.com/fgnass/domino/pull/142 for more information.
+      return NodeUtils.serializeOne(this, { nodeType: 0 });
     },
     set: function(v) {
       var document = this.ownerDocument;
